import path from 'path'
import Listr from 'listr'
import { projectInstall } from 'pkg-install'
import chalk from 'chalk'
import {
  move, mkdir, exists, removeDir
} from './helpers/fs-helpers'
import { parseArgumentsIntoOptions, promptForMissingOptions, cloneRepo } from './helpers'

const crateDirectoryForNewWidget = async ({ directory, widgetName }) => {
  if (directory) {
    if (exists(path.resolve(directory))) {
      throw new Error('Directory Exist please change name')
    }
    mkdir(path.resolve(directory))
  } else {
    if (exists(path.resolve(widgetName))) {
      throw new Error('Directory Exist please change name with argumen -d <name>')
    }
    mkdir(path.resolve(widgetName))
  }
}
const forkWidget = (options) => {
  if (options.directory) {
    move(path.resolve(options.tempGitPath, options.widgetCategory, options.widgetName),
      path.resolve(options.directory))
  } else {
    move(path.resolve(options.tempGitPath, options.widgetCategory, options.widgetName),
      path.resolve(options.widgetName))
  }
}

const cleanUnusedCode = async (options) => {
  removeDir(path.resolve(options.tempObj.name))
}
const installDependencies = (options) => {
  if (options.directory) {
    return projectInstall({
      cwd: path.resolve(options.directory),
      prefer: 'yarn'
    })
  }
  return projectInstall({
    cwd: path.resolve(options.widgetName),
    prefer: 'yarn'
  })
}
module.exports = async (args) => {
  let options = parseArgumentsIntoOptions(args)
  let tasks = new Listr([
    {
      title: 'Cloning data from main widget Repository',
      task: () => cloneRepo(options)
    }
  ])
  try {
    await tasks.run()
  } catch (e) {
    return chalk.bgRedBright.black(e)
  }
  options = await promptForMissingOptions(options)

  tasks = new Listr([
    {
      title: 'Creating New Directory',
      task: () => crateDirectoryForNewWidget(options)
    },
    {
      title: 'Forking Widget to new folder',
      task: () => forkWidget(options)
    },
    {
      title: 'Cleaning Extra Code',
      task: () => cleanUnusedCode(options)
    },
    {
      title: 'Installing dependencies',
      task: () => installDependencies(options)

    }
  ])
  try {
    await tasks.run()
  } catch (e) {
    chalk.bgRedBright.black(e)
  }
}
